# coding: utf-8

"""
    Flat API

    The Flat API allows you to easily extend the abilities of the [Flat Platform](https://flat.io), with a wide range of use cases including the following:  * Creating and importing new music scores using MusicXML, MIDI, Guitar Pro (GP3, GP4, GP5, GPX, GP), PowerTab, TuxGuitar and MuseScore files * Browsing, updating, copying, exporting the user's scores (for example in MP3, WAV or MIDI) * Managing educational resources with Flat for Education: creating & updating the organization accounts, the classes, rosters and assignments.  The Flat API is built on HTTP. Our API is RESTful It has predictable resource URLs. It returns HTTP response codes to indicate errors. It also accepts and returns JSON in the HTTP body. The [schema](/swagger.yaml) of this API follows the [OpenAPI Initiative (OAI) specification](https://www.openapis.org/), you can use and work with [compatible Swagger tools](http://swagger.io/open-source-integrations/). This API features Cross-Origin Resource Sharing (CORS) implemented in compliance with [W3C spec](https://www.w3.org/TR/cors/).  You can use your favorite HTTP/REST library for your programming language to use Flat's API. This specification and reference is [available on Github](https://github.com/FlatIO/api-reference).  Getting Started and learn more:  * [API Overview and introduction](https://flat.io/developers/docs/api/) * [Authentication (Personal Access Tokens or OAuth2)](https://flat.io/developers/docs/api/authentication.html) * [SDKs](https://flat.io/developers/docs/api/sdks.html) * [Rate Limits](https://flat.io/developers/docs/api/rate-limits.html) * [Changelog](https://flat.io/developers/docs/api/changelog.html) 

    The version of the OpenAPI document: 2.20.0
    Contact: developers@flat.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from flat_api.models.assignment_submission_comments import AssignmentSubmissionComments
from flat_api.models.assignment_submission_lti import AssignmentSubmissionLti
from flat_api.models.assignment_submission_playback_inner import AssignmentSubmissionPlaybackInner
from flat_api.models.assignment_submission_state import AssignmentSubmissionState
from flat_api.models.google_classroom_submission import GoogleClassroomSubmission
from flat_api.models.media_attachment import MediaAttachment
from flat_api.models.microsoft_graph_submission import MicrosoftGraphSubmission
from typing import Optional, Set
from typing_extensions import Self

class AssignmentSubmission(BaseModel):
    """
    Assignment Submission
    """ # noqa: E501
    id: StrictStr = Field(description="Unique identifier of the submission")
    state: AssignmentSubmissionState
    classroom: StrictStr = Field(description="Unique identifier of the classroom where the assignment was posted ")
    assignment: StrictStr = Field(description="Unique identifier of the assignment")
    creator: StrictStr = Field(description="The User identifier of the student who created the submission")
    creation_date: StrictStr = Field(description="The date when the submission was created", alias="creationDate")
    attachments: List[MediaAttachment]
    submission_date: Optional[StrictStr] = Field(default=None, description="The date when the student submitted their work", alias="submissionDate")
    return_date: Optional[StrictStr] = Field(default=None, description="The date when the teacher returned the work", alias="returnDate")
    return_creator: Optional[StrictStr] = Field(default=None, description="The User unique identifier of the teacher who returned the submission ", alias="returnCreator")
    grade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Optional grade. If unset, no grade was set.")
    draft_grade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Optional grade. If unset, no grade was set. This value is only visible by the teacher, and we will be set to `grade` once the teacher returns the submission", alias="draftGrade")
    max_points: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Optional max points for the grade. If set, a corresponding `draftGrade` or `grade` will be set.", alias="maxPoints")
    exercises_ids: Optional[List[StrictStr]] = Field(default=None, description="The ids of exercises when they need to be in a specific order", alias="exercisesIds")
    playback: List[AssignmentSubmissionPlaybackInner]
    comments: AssignmentSubmissionComments
    google_classroom: Optional[GoogleClassroomSubmission] = Field(default=None, alias="googleClassroom")
    microsoft_graph: Optional[MicrosoftGraphSubmission] = Field(default=None, alias="microsoftGraph")
    lti: Optional[AssignmentSubmissionLti] = None
    __properties: ClassVar[List[str]] = ["id", "state", "classroom", "assignment", "creator", "creationDate", "attachments", "submissionDate", "returnDate", "returnCreator", "grade", "draftGrade", "maxPoints", "exercisesIds", "playback", "comments", "googleClassroom", "microsoftGraph", "lti"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AssignmentSubmission from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item in self.attachments:
                if _item:
                    _items.append(_item.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in playback (list)
        _items = []
        if self.playback:
            for _item in self.playback:
                if _item:
                    _items.append(_item.to_dict())
            _dict['playback'] = _items
        # override the default output from pydantic by calling `to_dict()` of comments
        if self.comments:
            _dict['comments'] = self.comments.to_dict()
        # override the default output from pydantic by calling `to_dict()` of google_classroom
        if self.google_classroom:
            _dict['googleClassroom'] = self.google_classroom.to_dict()
        # override the default output from pydantic by calling `to_dict()` of microsoft_graph
        if self.microsoft_graph:
            _dict['microsoftGraph'] = self.microsoft_graph.to_dict()
        # override the default output from pydantic by calling `to_dict()` of lti
        if self.lti:
            _dict['lti'] = self.lti.to_dict()
        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if draft_grade (nullable) is None
        # and model_fields_set contains the field
        if self.draft_grade is None and "draft_grade" in self.model_fields_set:
            _dict['draftGrade'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AssignmentSubmission from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "state": obj.get("state"),
            "classroom": obj.get("classroom"),
            "assignment": obj.get("assignment"),
            "creator": obj.get("creator"),
            "creationDate": obj.get("creationDate"),
            "attachments": [MediaAttachment.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "submissionDate": obj.get("submissionDate"),
            "returnDate": obj.get("returnDate"),
            "returnCreator": obj.get("returnCreator"),
            "grade": obj.get("grade"),
            "draftGrade": obj.get("draftGrade"),
            "maxPoints": obj.get("maxPoints"),
            "exercisesIds": obj.get("exercisesIds"),
            "playback": [AssignmentSubmissionPlaybackInner.from_dict(_item) for _item in obj["playback"]] if obj.get("playback") is not None else None,
            "comments": AssignmentSubmissionComments.from_dict(obj["comments"]) if obj.get("comments") is not None else None,
            "googleClassroom": GoogleClassroomSubmission.from_dict(obj["googleClassroom"]) if obj.get("googleClassroom") is not None else None,
            "microsoftGraph": MicrosoftGraphSubmission.from_dict(obj["microsoftGraph"]) if obj.get("microsoftGraph") is not None else None,
            "lti": AssignmentSubmissionLti.from_dict(obj["lti"]) if obj.get("lti") is not None else None
        })
        return _obj


