# coding: utf-8

"""
    Flat API

    The Flat API allows you to easily extend the abilities of the [Flat Platform](https://flat.io), with a wide range of use cases including the following:  * Creating and importing new music scores using MusicXML, MIDI, Guitar Pro (GP3, GP4, GP5, GPX, GP), PowerTab, TuxGuitar and MuseScore files * Browsing, updating, copying, exporting the user's scores (for example in MP3, WAV or MIDI) * Managing educational resources with Flat for Education: creating & updating the organization accounts, the classes, rosters and assignments.  The Flat API is built on HTTP. Our API is RESTful It has predictable resource URLs. It returns HTTP response codes to indicate errors. It also accepts and returns JSON in the HTTP body. The [schema](/swagger.yaml) of this API follows the [OpenAPI Initiative (OAI) specification](https://www.openapis.org/), you can use and work with [compatible Swagger tools](http://swagger.io/open-source-integrations/). This API features Cross-Origin Resource Sharing (CORS) implemented in compliance with [W3C spec](https://www.w3.org/TR/cors/).  You can use your favorite HTTP/REST library for your programming language to use Flat's API. This specification and reference is [available on Github](https://github.com/FlatIO/api-reference).  Getting Started and learn more:  * [API Overview and introduction](https://flat.io/developers/docs/api/) * [Authentication (Personal Access Tokens or OAuth2)](https://flat.io/developers/docs/api/authentication.html) * [SDKs](https://flat.io/developers/docs/api/sdks.html) * [Rate Limits](https://flat.io/developers/docs/api/rate-limits.html) * [Changelog](https://flat.io/developers/docs/api/changelog.html) 

    The version of the OpenAPI document: 2.20.0
    Contact: developers@flat.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from flat_api.models.media_score_sharing_mode import MediaScoreSharingMode
from typing import Optional, Set
from typing_extensions import Self

class MediaAttachment(BaseModel):
    """
    Media attachment. The API will automatically resolve the details, oEmbed, and media available if possible and return them in this object 
    """ # noqa: E501
    type: StrictStr = Field(description="The type of the assignment resolved: * `rich`, `photo`, `video` are automatically resolved as `link` * A `flat` attachment is a score document where the unique identifier will be specified in the `score` property. Its sharing mode will be provided in the `sharingMode` property. ")
    score: Optional[StrictStr] = Field(default=None, description="An unique Flat score identifier")
    revision: Optional[StrictStr] = Field(default=None, description="An unique revision identifier of a score")
    worksheet: Optional[StrictStr] = Field(default=None, description="An unique worksheet identifier")
    dedicated: Optional[StrictBool] = Field(default=None, description="True if the resource is dedicated for the assignment (for scores and worksheets), meaning on the user-side this one is stored in the assignment")
    track: Optional[StrictStr] = Field(default=None, description="A unique track identifier")
    sharing_mode: Optional[MediaScoreSharingMode] = Field(default=None, alias="sharingMode")
    lock_score_template: Optional[StrictBool] = Field(default=None, description="To be used with a score attached in `sharingMode` `copy` (score used as template). If true, students won't be able to change the original notes of the template.", alias="lockScoreTemplate")
    title: Optional[StrictStr] = Field(default=None, description="The resolved title of the attachment")
    description: Optional[StrictStr] = Field(default=None, description="The resolved description of the attachment")
    html: Optional[StrictStr] = Field(default=None, description="If the attachment type is `rich` or `video`, the HTML code of the media to display ")
    html_width: Optional[StrictStr] = Field(default=None, description="If the `html` is available, the width of the widget", alias="htmlWidth")
    html_height: Optional[StrictStr] = Field(default=None, description="If the `html` is available, the height of the widget", alias="htmlHeight")
    url: Optional[StrictStr] = Field(default=None, description="The url of the attachment")
    thumbnail_url: Optional[StrictStr] = Field(default=None, description="If the attachment type is `rich`, `video`, `photo` or `link`, a displayable thumbnail for this attachment ", alias="thumbnailUrl")
    thumbnail_width: Optional[StrictInt] = Field(default=None, description="If the `thumbnailUrl` is available, the width of the thumbnail ", alias="thumbnailWidth")
    thumbnail_height: Optional[StrictInt] = Field(default=None, description="If the `thumbnailUrl` is available, the width of the thumbnail ", alias="thumbnailHeight")
    author_name: Optional[StrictStr] = Field(default=None, description="The resolved author name of the attachment", alias="authorName")
    author_url: Optional[StrictStr] = Field(default=None, description="The resolved author url of the attachment", alias="authorUrl")
    icon_url: Optional[StrictStr] = Field(default=None, description="The URL of the icon", alias="iconUrl")
    mime_type: Optional[StrictStr] = Field(default=None, description="The mine type of the file", alias="mimeType")
    google_drive_file_id: Optional[StrictStr] = Field(default=None, description="The ID of the Google Drive File", alias="googleDriveFileId")
    __properties: ClassVar[List[str]] = ["type", "score", "revision", "worksheet", "dedicated", "track", "sharingMode", "lockScoreTemplate", "title", "description", "html", "htmlWidth", "htmlHeight", "url", "thumbnailUrl", "thumbnailWidth", "thumbnailHeight", "authorName", "authorUrl", "iconUrl", "mimeType", "googleDriveFileId"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['rich', 'photo', 'video', 'link', 'flat', 'googleDrive', 'worksheet', 'performance']):
            raise ValueError("must be one of enum values ('rich', 'photo', 'video', 'link', 'flat', 'googleDrive', 'worksheet', 'performance')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MediaAttachment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MediaAttachment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "score": obj.get("score"),
            "revision": obj.get("revision"),
            "worksheet": obj.get("worksheet"),
            "dedicated": obj.get("dedicated"),
            "track": obj.get("track"),
            "sharingMode": obj.get("sharingMode"),
            "lockScoreTemplate": obj.get("lockScoreTemplate"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "html": obj.get("html"),
            "htmlWidth": obj.get("htmlWidth"),
            "htmlHeight": obj.get("htmlHeight"),
            "url": obj.get("url"),
            "thumbnailUrl": obj.get("thumbnailUrl"),
            "thumbnailWidth": obj.get("thumbnailWidth"),
            "thumbnailHeight": obj.get("thumbnailHeight"),
            "authorName": obj.get("authorName"),
            "authorUrl": obj.get("authorUrl"),
            "iconUrl": obj.get("iconUrl"),
            "mimeType": obj.get("mimeType"),
            "googleDriveFileId": obj.get("googleDriveFileId")
        })
        return _obj


