# coding: utf-8

"""
    Flat API

    The Flat API allows you to easily extend the abilities of the [Flat Platform](https://flat.io), with a wide range of use cases including the following:  * Creating and importing new music scores using MusicXML, MIDI, Guitar Pro (GP3, GP4, GP5, GPX, GP), PowerTab, TuxGuitar and MuseScore files * Browsing, updating, copying, exporting the user's scores (for example in MP3, WAV or MIDI) * Managing educational resources with Flat for Education: creating & updating the organization accounts, the classes, rosters and assignments.  The Flat API is built on HTTP. Our API is RESTful It has predictable resource URLs. It returns HTTP response codes to indicate errors. It also accepts and returns JSON in the HTTP body. The [schema](/swagger.yaml) of this API follows the [OpenAPI Initiative (OAI) specification](https://www.openapis.org/), you can use and work with [compatible Swagger tools](http://swagger.io/open-source-integrations/). This API features Cross-Origin Resource Sharing (CORS) implemented in compliance with [W3C spec](https://www.w3.org/TR/cors/).  You can use your favorite HTTP/REST library for your programming language to use Flat's API. This specification and reference is [available on Github](https://github.com/FlatIO/api-reference).  Getting Started and learn more:  * [API Overview and introduction](https://flat.io/developers/docs/api/) * [Authentication (Personal Access Tokens or OAuth2)](https://flat.io/developers/docs/api/authentication.html) * [SDKs](https://flat.io/developers/docs/api/sdks.html) * [Rate Limits](https://flat.io/developers/docs/api/rate-limits.html) * [Changelog](https://flat.io/developers/docs/api/changelog.html) 

    The version of the OpenAPI document: 2.20.0
    Contact: developers@flat.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from flat_api.models.class_roles import ClassRoles
from flat_api.models.organization_roles import OrganizationRoles
from flat_api.models.tutteo_product import TutteoProduct
from typing import Optional, Set
from typing_extensions import Self

class UserPublicSummary(BaseModel):
    """
    UserPublicSummary
    """ # noqa: E501
    id: StrictStr = Field(description="The user unique identifier")
    type: StrictStr = Field(description="The type of user account")
    product: TutteoProduct
    username: StrictStr = Field(description="The user name (unique for the organization)")
    printable_name: Optional[StrictStr] = Field(default=None, description="The name that can be directly printed (name, firstname & lastname, or username)", alias="printableName")
    firstname: Optional[StrictStr] = Field(default=None, description="Firstname of the user (for education users)")
    lastname: Optional[StrictStr] = Field(default=None, description="Lastname of the user (for education users)")
    name: Optional[StrictStr] = Field(default=None, description="A displayable name for the user (for consumer users)")
    picture: Optional[StrictStr] = Field(description="The URL of the picture to display")
    badges: Optional[List[StrictStr]] = Field(default=None, description="List of badges for the user profile:  - `power` - `staff` - `composerOfTheMonth` - `ambassador` - `challenge` ")
    organization: Optional[StrictStr] = Field(default=None, description="Organization ID (for Edu users only)")
    organization_role: Optional[OrganizationRoles] = Field(default=None, alias="organizationRole")
    class_role: Optional[ClassRoles] = Field(default=None, alias="classRole")
    html_url: Optional[StrictStr] = Field(default=None, description="Link to user profile (for Indiv. users only)", alias="htmlUrl")
    __properties: ClassVar[List[str]] = ["id", "type", "product", "username", "printableName", "firstname", "lastname", "name", "picture", "badges", "organization", "organizationRole", "classRole", "htmlUrl"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['user', 'guest']):
            raise ValueError("must be one of enum values ('user', 'guest')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserPublicSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if picture (nullable) is None
        # and model_fields_set contains the field
        if self.picture is None and "picture" in self.model_fields_set:
            _dict['picture'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserPublicSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "product": obj.get("product"),
            "username": obj.get("username"),
            "printableName": obj.get("printableName"),
            "firstname": obj.get("firstname"),
            "lastname": obj.get("lastname"),
            "name": obj.get("name"),
            "picture": obj.get("picture"),
            "badges": obj.get("badges"),
            "organization": obj.get("organization"),
            "organizationRole": obj.get("organizationRole"),
            "classRole": obj.get("classRole"),
            "htmlUrl": obj.get("htmlUrl")
        })
        return _obj


